@@ -1,4 +1,4 @@
-package Dist::Zilla::PluginBundle::Author::Plicease 2.30 {
+package Dist::Zilla::PluginBundle::Author::Plicease 2.31 {
 
   use 5.014;
   use Moose;
@@ -31,7 +31,7 @@ package Dist::Zilla::PluginBundle::Author::Plicease 2.30 {
 
   my %plugin_versions = qw(
     Alien                0.023
-    Author::Plicease.*   2.30
+    Author::Plicease.*   2.31
     OurPkgVersion        0.12
     MinimumPerl          1.006
     InstallGuide         1.200006
@@ -251,6 +251,15 @@ package Dist::Zilla::PluginBundle::Author::Plicease 2.30 {
         },
       ]);
     }
+
+    if($self->payload->{copy_mm})
+    {
+      $self->_my_add_plugin([
+        'CopyFilesFromBuild' => {
+          copy => [ 'Makefile.PL' ],
+        },
+      ]);
+    }
   
     unless('bakeini' eq (Dist::Zilla::Util::CurrentCmd::current_cmd() ||'') )
     {
@@ -373,7 +382,7 @@ Dist::Zilla::PluginBundle::Author::Plicease - Dist::Zilla plugin bundle used by
 
 =head1 VERSION
 
-version 2.30
+version 2.31
 
 =head1 SYNOPSIS
 
@@ -572,6 +581,10 @@ Exclude them from gather.
 This allows other developers to use the dist from the git checkout, without needing
 to install L<Dist::Zilla> and L<Dist::Zilla::PluginBundle::Author::Plicease>.
 
+=head2 copy_mm
+
+Same as C<copy_mb> but for EUMM.
+
 =head2 allow_dirty
 
 Additional dirty allowed file passed to @Git.
